@@ -1,5 +1,5 @@
 # Verilog::Getopt.pm -- Verilog command line parsing
-# $Id: Getopt.pm 11992 2006-01-16 18:59:58Z wsnyder $
+# $Id: Getopt.pm 13414 2006-02-06 18:19:45Z wsnyder $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
@@ -29,13 +29,14 @@ use Cwd;
 ######################################################################
 #### Configuration Section
 
-$VERSION = '2.340';
+$VERSION = '2.341';
 
 # Basenames we should ignore when recursing directories,
 # Because they contain large files of no relevance
 foreach ( '.', '..',
 	  'CVS',
 	  '.svn',
+	  '.snapshot',
 	  'blib',
 	  ) {
     $Skip_Basenames{$_} = 1;
@@ -59,6 +60,7 @@ sub new {
 		vcs_style => 1,
 		fileline => 'Command_Line',
 		unparsed => [],
+		define_warnings => 1,
 		@_
 		};
     bless $self, $class;
@@ -443,7 +445,8 @@ sub define {
 	my $params = shift||"";
 	print "Define $token $params= $value\n" if $Debug;
 	my $oldval = $self->{defines}{$token};
-	(!defined $oldval or ($oldval eq $value)) or warn "%Warning: ".$self->fileline().": Redefining `$token\n";
+	(!defined $oldval or ($oldval eq $value) or !$self->{define_warnings})
+	    or warn "%Warning: ".$self->fileline().": Redefining `$token\n";
 	if ($params) {
 	    $self->{defines}{$token} = [$value, $params];
 	} else {
@@ -455,10 +458,24 @@ sub undef {
     my $self = shift;
     my $token = shift;
     my $oldval = $self->{defines}{$token};
-    (defined $oldval) or carp "%Warning: ".$self->fileline().": No definition to undef for $token,";
+    (defined $oldval or !$self->{define_warnings})
+	or carp "%Warning: ".$self->fileline().": No definition to undef for $token,";
     delete $self->{defines}{$token};
 }
 
+sub remove_defines {
+    my $self = shift;
+    my $sym = shift;
+    my $val = "x";
+    while (defined $val) {
+	last if $sym eq $val;
+	(my $xsym = $sym) =~ s/^\`//;
+	$val = $self->defvalue_nowarn($xsym);  #Undef if not found
+	$sym = $val if defined $val;
+    }
+    return $sym;
+}
+
 ######################################################################
 ### Package return
 1;
@@ -601,6 +618,10 @@ Returns reference to list of libraries.  With argument, adds that library.
 Returns reference to list of module directories.  With argument, adds that
 directory.
 
+=item $self->remove_defines ( $token )
+
+Return string with any definitions in the token removed.
+
 =item $self->undef ( $token )
 
 Deletes a hash element that is used to fulfill define references.  This
